
function [lon_era,lat_era,lonvec,latvec,sss,index, ...
        sst,netheat,eminusp,taux,tauy]=loaderayear(year);

% function [lon_era,lat_era,lonvec,latvec,sss,index, ...
%        sst,netheat,eminusp,taux,tauy]=loaderayear(year);
%
% load a year (=1979 through 1993) of monthly 
% observations from the ERA-15 reanalysis fields.
% Output is mean + anomaly.  For the climatology alone,
% input a negative number for "year".

directory='/phod007/lumpkin/era15';

eval(['lon_era=getnc(''',directory, ...
	'/uflx.nc'',''lon'');']);
% break data at dateline instead of prime meridian
q=find(lon_era>=180);
lon_era(q)=lon_era(q)-360;
[lon_era,ind_lon]=sort(lon_era);
eval(['lat_era=getnc(''',directory, ...
        '/uflx.nc'',''lat'');']);
%eval(['landmask=getnc(''',directory, ...
%       '/uflx.nc'',''lsmask'');']);
% redefine so landmask=1 over ocean, NaN over land
%landmask=landmask+1;
%landmask(find(~landmask))=NaN;

if (year<0)
    disp('Loading ERA-15 long-term monthly means');
    load /phod007/lumpkin/era15/era;
    return;
else
  if (year>45 & year<1900);
    year=year+1900;
  elseif (year>=0 & year<45);
    year=year+2000;
  end;
  fileext='.nc';
  fprintf('Loading ERA-15 fields, year %d.\n',year);
  eval(['t=getnc(''',directory, ...
        '/uflx',fileext,''',''time'');']);
  % time: hours since 1/1/1 00:00:00
  t=t/24+julian([1 1 13 0 0 0]);
  q=find(t>=julian([year,1,1,0,0,0]) & ...
	t<=julian([year,12,31,0,0,0]));
  corner=[q(1) -1 -1];
  endpt=[last(q) -1 -1];
  stride=[1 -1 -1];
end

% load, changing all heat flux signs to retain
% convention that POSITIVE = heat INTO ocean
eval(['latent=getnc(''',directory, ...
        '/lhtfl',fileext,''',''lhtfl'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['sensible=getnc(''',directory, ...
        '/shtfl',fileext,''',''shtfl'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['longwave=getnc(''',directory, ...
        '/nlwrs',fileext,''',''nlwrf'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['shortwave=getnc(''',directory, ...
        '/nswrs',fileext,''',''nswrf'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['sst=getnc(''',directory, ...
        '/skt',fileext,''',''skt'',' ...
        'corner,endpt,stride,-1,1);']);
% convert from K to degC
sst=sst-273;
eval(['taux=getnc(''',directory, ...
        '/uflx',fileext,''',''uflx'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['tauy=getnc(''',directory, ...
        '/vflx',fileext,''',''vflx'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['precip1=getnc(''',directory, ...
        '/largescale_prate',fileext,''',''lrgsclprec'',' ...
        'corner,endpt,stride,-1,1);']);
eval(['precip2=getnc(''',directory, ...
        '/convect_prate',fileext,''',''convprec'',' ...
        'corner,endpt,stride,-1,1);']);
% sign convention for evap: negative values.
eval(['evap=-getnc(''',directory, ...
        '/evap',fileext,''',''evap'',' ...
        'corner,endpt,stride,-1,1);']);

% define netheat
netheat=latent+sensible+longwave+shortwave;

% NOTE: unlike NCEP,, the ERA fields provide
% evap, precip in METERS/MONTH, not in kg/m^2/s.
%  (UWM/COADS: mm/3 hours)
precip=precip1+precip2; clear precip1 precip2;
% convert E, P to m/s :
% ncdump -h says units of E, P are "m".  From consistency
% check (see below), units must be m/6 hours.
% This makes sense ... time step of ECMWF is 6-hourly,
% so the accumulation is meters per six hours.
precip=precip/6/3600;
evap=evap/6/3600;

%% consistency check: evaporation from latent heat.
%Le=(2494-2.2*sst)*1000;		% lat.heat of evap. [J/kg]
%evap2=-latent./Le;		% evaporation [kg/m^2/s]
%% convert to m/s
%evap2=evap2/1000;  
%% evap2 is equal to evap except very near poles

% calculate eminusp
eminusp=evap-precip;
clear evap precip;

clear latent sensible longwave shortwave;

% re-order variables so longitude is -180:180
netheat=netheat(:,:,ind_lon);
sst=sst(:,:,ind_lon);
taux=taux(:,:,ind_lon);
tauy=tauy(:,:,ind_lon);
eminusp=eminusp(:,:,ind_lon);
clear ind_lon;

% reshape data to have the same format as
% the COADS fields (time,index)
eval(['load ',directory,'/landmask landmask']);
% redefine so landmask=1 over ocean, NaN over land
landmask=landmask+1;
landmask(find(~landmask))=NaN;
index=1:size(landmask,1)*size(landmask,2);
landmask=reshape(landmask, ...
	[1 size(landmask,1)*size(landmask,2)]);
lonvec=ones(length(lat_era),1)*lon_era';
latvec=lat_era*ones(1,length(lon_era));
lonvec=reshape(lonvec, ...
	[1 size(landmask,1)*size(landmask,2)]);
latvec=reshape(latvec, ...
        [1 size(landmask,1)*size(landmask,2)]);
netheat=reshape(netheat,[size(netheat,1) ...
	size(netheat,2)*size(netheat,3)]);
sst=reshape(sst,[size(netheat,1) ...
        size(netheat,2)*size(netheat,3)]);
taux=reshape(taux,[size(netheat,1) ...
        size(netheat,2)*size(netheat,3)]);
tauy=reshape(tauy,[size(netheat,1) ...
        size(netheat,2)*size(netheat,3)]);
eminusp=reshape(eminusp,[size(netheat,1) ...
        size(netheat,2)*size(netheat,3)]);

% retain values over the ocean
q=find(isfinite(landmask));
index=index(q);
lonvec=lonvec(q);
latvec=latvec(q);
netheat=netheat(:,q);
sst=sst(:,q);
taux=taux(:,q);
tauy=tauy(:,q);
eminusp=eminusp(:,q);
clear landmask

%F=NaN*ones(length(lat_era),length(lon_era));
%F(index)=(1000*3600*24*365.24)*mean(eminusp,1);
%patchmap(lon_era,lat_era,F);
%colorbarvert

% load Levitus94 sea-surface salinity, interpolated
% onto NCEP grid via makesss.m (in NCEP directory)
eval(['load ',directory,'/sss sss;']);

% NaN-out values which contain ice temp in sst
% (allow a 1 psu increase in sss to account
% for possible monthly anomaly)
sstf=sw_fp(sss+1,zeros(size(sss)));
q=find(sst<sstf | isnan(sstf));
sst(q)=NaN;
eminusp(q)=NaN;
netheat(q)=NaN;
taux(q)=NaN;
tauy(q)=NaN;


