% plotheat_ant_inv - plot the heat fluxes against
% Antarctica from ERA15.  In a second figure,
% plot heat fluxes with adjustments (derived
% by global inverse model) consistent with 
% bottom/deep water overturning across S4.

clear all; close all;

boxmodeldirec='/phod007/lumpkin/dobox/global';

% load heat flux
[lon_coads,lat_coads,lonvec,latvec,sss,index, ...
        sst,netheat,eminusp,taux,tauy]=loaderayear(-99);

% truncate north of S4
load /phod007/lumpkin/dobox/sections/s4comp
q=find(latvec>max(lat));
truncatecoads;
Lat=max(lat);

% calculate mean heat flux
H=NaN*ones(length(lat_coads),length(lon_coads));
H(index)=nanmean(netheat);

% plot unadjusted mean
figure(2);
subplot(211)
patchmap(lon_coads,lat_coads,H,[-40 160]);
overlay;
PWD=pwd;
eval(['cd ',boxmodeldirec]);
hold on; plotsections;
eval(['cd ',PWD]);
% load polygon surrounding Antarctic coast
% (to be used later, while in box model directory)
load antcoast


% Now calculate adjusted mean net heat flux.
% Use output from plotso_heat
eval(['cd ',boxmodeldirec]);
load heatloss_ant Fh Fh_ap

BoxNum=[getboxnum(-110,-70) ... % Ross
        getboxnum(0,-65) ...    % Outer Wedell
        getboxnum(-45,-75) ...  % Inner Weddell
        getboxnum(75,-65)];

% The box inverse model gives adjustments as a function
% of density.  Apply these adjustments to the climatology
% as follows:  
%   1. calculate the gridded field of maximum sfc gamma
%       over the 12 climatological months.
%       Note that this will not contain the densest layers
%       (for ERA15, the densest value is 28.02).
%   2. for layer N, identify where it outcrops and calculate
%       the total area A of these grids.
%       If N>max(G), assign the adjustment to a set of
%       grid points against Antarctica (hard-coded).
%   3. adjust the net heat flux H in these grid points by
%       (Fh(N)-Fh_ap(N))*1e15 / A 

% calculate area A of each grid point;
[A,dx,dy]=sw_area(lon_coads,lat_coads);

% calculate maximum density
G=NaN*ones(length(lat_coads),length(lon_coads),12);
for i=1:12;
    g=gamman(sss(i,:),sst(i,:),zeros(size(sst(i,:))), ...
        lonvec,latvec);
    Gt=NaN*ones(length(lat_coads),length(lon_coads));
    Gt(index)=g;
    G(:,:,i)=Gt;
end;
G=max(G,[],3);

% set values against Antarctic coast to 999
lonmat=ones(length(lat_coads),1)*lon_coads';
latmat=lat_coads*ones(1,length(lon_coads));
q=find(isinpoly(lonmat,latmat,lonantcoast,latantcoast));
G(q)=999;
q=find(G<999);
maxG=max(G(q));

glev;
% identify densest layer present in climatology
maxlay=max(find(glevels<=maxG));


H_adj=H;
for boxnum=1:length(BoxNum);
    eval(['load boxcoords',num2str(BoxNum(boxnum))]);
    q=find(isinpoly(lonmat,latmat,lon,lat));
    
    for layernum=1:maxlay;
        q2=find(G(q)>gamma2(layernum) & ...
                G(q)<gamma2(layernum+1));
        if (length(q2))
            adj=Fh(layernum,boxnum)-Fh_ap(layernum,boxnum);
            % convert from PW to W/m^2
            adj=adj*1e15/sum(A(q(q2)));
            H_adj(q(q2))=H(q(q2))+adj;
        end;
    end;
    q2=find(G(q)>glayers(maxlay));
    layernum=maxlay+1:length(glayers);
    adj=sum(Fh(layernum,boxnum)-Fh_ap(layernum,boxnum));
    % convert from PW to W/m^2
    adj=adj*1e15/sum(A(q(q2)));
    H_adj(q(q2))=H(q(q2))+adj;
    
end;

figure(2);
patchmap(lon_coads,lat_coads,H_adj-H,[-20 0])
axis([-180 180 -90 Lat])
set(gca,'dataaspectratio',[5 1 1])
tiks=-180:90:180;labs=deglabels(tiks,2);
set(gca,'xtick',tiks,'xticklabel',labs)
tiks=-90:10:-60;labs=deglabels(tiks,1);
set(gca,'ytick',tiks,'yticklabel',labs)

eval(['cd ',PWD]);